pub trait CacheKey {
// Required method
fn cache_key(&self, state: &mut CacheKeyHasher);
}Expand description
Trait for values that can contribute to a deterministic package cache key.
pub trait CacheKey {
// Required method
fn cache_key(&self, state: &mut CacheKeyHasher);
}Trait for values that can contribute to a deterministic package cache key.